habitat.sensors.base
====================

.. automodule:: habitat.sensors.base

   
   
   .. rubric:: Functions

   .. autosummary::
   
      ascii_float
      ascii_int
      constant
      string
   
   

   
   
   

   
   
   